# XML Connector
**Many feeds use the XML format. This connector groups together all the `Actions` that process an XML stream to retrieve jobs.**

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |